@FunctionalInterface
public interface ValidationRule<T> {
    String validate(T object);

    // Static helper methods to define common rules
    static <T> ValidationRule<T> notNull(String fieldName, java.util.function.Function<T, Object> getter) {
        return object -> getter.apply(object) == null ? fieldName + " must not be null" : null;
    }

    static <T> ValidationRule<T> notBlank(String fieldName, java.util.function.Function<T, String> getter) {
        return object -> {
            String val = getter.apply(object);
            return (val == null || val.trim().isEmpty()) ? fieldName + " must not be blank" : null;
        };
    }

    static <T> ValidationRule<T> minLength(String fieldName, java.util.function.Function<T, String> getter, int min) {
        return object -> {
            String val = getter.apply(object);
            return (val != null && val.length() < min) ? fieldName + " must be at least " + min + " characters" : null;
        };
    }
}
